/*
    Copyright 2007 Luigi Auriemma

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA

    http://www.gnu.org/licenses/gpl.txt

*/

#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>



#ifdef WIN32
    #include <windows.h>

    void easywebcam_reg(void);
#endif



#define VER         "0.1"
#define BUFFSZ      512
#define KEYPATH     "Software\\VB and VBA Program Settings\\EasyWebCam\\data"



uint8_t *easywebcam_pwd(uint8_t *pwd);



int main(int argc, char *argv[]) {
    uint8_t buff[BUFFSZ];

    setbuf(stdout, NULL);

    fputs("\n"
        "EasyWebCam passwords decoder "VER"\n"
        "by Luigi Auriemma\n"
        "e-mail: aluigi@autistici.org\n"
        "web:    aluigi.org\n"
        "\n", stdout);

    if(argc < 2) {
        printf("\n"
            "Usage: %s [encoded_password]\n"
            "\n", argv[0]);

#ifdef WIN32
        easywebcam_reg();

        printf("\nPress RETURN to quit\n");
        fgetc(stdin);
#else
        exit(1);
#endif
    } else {
        sprintf(buff, "%.*s", sizeof(buff), argv[1]);
        printf("  password:      %s\n", easywebcam_pwd(buff));
    }

    return(0);
}



#ifdef WIN32

int regkey(HKEY hKey, LPCTSTR lpSubKey, LPTSTR lpValueName, uint8_t *buff, int len) {
    HKEY    key;

    buff[0] = 0;

    if(RegOpenKeyEx(hKey, lpSubKey, 0, KEY_READ, &key) != ERROR_SUCCESS) {
        return(-1);
    }
    if(RegQueryValueEx(key, lpValueName, NULL, NULL, buff, (void *)&len) != ERROR_SUCCESS) {
        RegCloseKey(key);
        return(-1);
    }
    RegCloseKey(key);

    return(0);
}



void easywebcam_reg(void) {
    uint8_t buff[BUFFSZ];

    if(!regkey(HKEY_CURRENT_USER, KEYPATH, "ftp",       buff, sizeof(buff)))
        printf("  ftp:           %s\n", buff);
    if(!regkey(HKEY_CURRENT_USER, KEYPATH, "username",  buff, sizeof(buff)))
        printf("  username:      %s\n", buff);
    if(!regkey(HKEY_CURRENT_USER, KEYPATH, "pass",      buff, sizeof(buff)))
        printf("  password:      %s\n", easywebcam_pwd(buff));

    if(!regkey(HKEY_CURRENT_USER, KEYPATH, "wapftp",    buff, sizeof(buff)))
        printf("  wap ftp:       %s\n", buff);
    if(!regkey(HKEY_CURRENT_USER, KEYPATH, "waplogin",  buff, sizeof(buff)))
        printf("  wap username:  %s\n", buff);
    if(!regkey(HKEY_CURRENT_USER, KEYPATH, "wappass",   buff, sizeof(buff)))
        printf("  wap password:  %s\n", easywebcam_pwd(buff));
}

#endif



uint8_t *easywebcam_pwd(uint8_t *pwd) {
    uint8_t     *p;

    for(p = pwd; *p; p++) {
        *p = (*p >> 1) - 2;
    }
    return(pwd);
}



